summaryrefslogtreecommitdiffstats
path: root/kjs/identifier.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjs/identifier.h')
-rw-r--r--kjs/identifier.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kjs/identifier.h b/kjs/identifier.h
index 5867077d8..e479547f6 100644
--- a/kjs/identifier.h
+++ b/kjs/identifier.h
@@ -52,9 +52,9 @@ namespace KJS {
const UString &ustring() const { return _ustring; }
DOM::DOMString string() const;
/**
* returns a QString of the identifier
*/
- QString qstring() const;
+ TQString qstring() const;
/**
* returns a UChar pointer to the string of the identifier with a size defined by @ref size().
@@ -52,9 +52,9 @@ namespace KJS {
DOM::DOMString string() const;
/**
- * returns a QString of the identifier
+ * returns a TQString of the identifier
*/